@@ -1,4 +1,3 @@
-import config from 'config';
 import { replaceInTemplate } from '@tamanu/utils/replaceInTemplate';
 import { NotFoundError } from '@tamanu/errors';
 import { PATIENT_COMMUNICATION_CHANNELS, PATIENT_COMMUNICATION_TYPES } from '@tamanu/constants';
@@ -11,7 +10,8 @@ export class PortalCommunicationProcessor extends BaseCommunicationProcessor {
   }
 
   async transformContent({ content, patientId, type }) {
-    const { models } = this.context.store;
+    const {store, settings} = this.context;
+    const { models } = store;
     const portalOneTimeTokenService = new PortalOneTimeTokenService(models);
     const portalUser = await models.PortalUser.findOne({ where: { patientId } });
 
@@ -20,7 +20,11 @@ export class PortalCommunicationProcessor extends BaseCommunicationProcessor {
     }
 
     const portalUserId = portalUser.id;
-    const baseUrl = config.patientPortal.portalUrl;
+    const baseUrl = await settings.get('patientPortal.baseUrl');
+
+    if (!baseUrl) {
+      throw new Error('Patient portal base URL is not configured (patientPortal.baseUrl)');
+    }
 
     // Send form link and login code to a registered user
     if (type === PATIENT_COMMUNICATION_TYPES.PATIENT_PORTAL_REGISTERED_FORM) {
